==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkInformationIterator.java <==
// java wrapper for vtkInformationIterator object
//

package vtk;
import vtk.*;

public class vtkInformationIterator extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInformation_2(vtkInformation id0);
  public void SetInformation(vtkInformation id0)
    { SetInformation_2(id0); }

  private native long GetInformation_3();
  public vtkInformation GetInformation() {
    long temp = GetInformation_3();

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInformationWeak_4(vtkInformation id0);
  public void SetInformationWeak(vtkInformation id0)
    { SetInformationWeak_4(id0); }

  private native void InitTraversal_5();
  public void InitTraversal()
    { InitTraversal_5(); }

  private native void GoToFirstItem_6();
  public void GoToFirstItem()
    { GoToFirstItem_6(); }

  private native void GoToNextItem_7();
  public void GoToNextItem()
    { GoToNextItem_7(); }

  private native int IsDoneWithTraversal_8();
  public int IsDoneWithTraversal()
    { return IsDoneWithTraversal_8(); }

  private native long GetCurrentKey_9();
  public vtkInformationKey GetCurrentKey() {
    long temp = GetCurrentKey_9();

    if (temp == 0) return null;
    return (vtkInformationKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkInformationIterator() { super(); }

  public vtkInformationIterator(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkInformationIterator.java <==
// java wrapper for vtkInformationIterator object
//

package vtk;
import vtk.*;

public class vtkInformationIterator extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInformation_2(vtkInformation id0);
  public void SetInformation(vtkInformation id0)
    { SetInformation_2(id0); }

  private native long GetInformation_3();
  public vtkInformation GetInformation() {
    long temp = GetInformation_3();

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInformationWeak_4(vtkInformation id0);
  public void SetInformationWeak(vtkInformation id0)
    { SetInformationWeak_4(id0); }

  private native void InitTraversal_5();
  public void InitTraversal()
    { InitTraversal_5(); }

  private native void GoToFirstItem_6();
  public void GoToFirstItem()
    { GoToFirstItem_6(); }

  private native void GoToNextItem_7();
  public void GoToNextItem()
    { GoToNextItem_7(); }

  private native int IsDoneWithTraversal_8();
  public int IsDoneWithTraversal()
    { return IsDoneWithTraversal_8(); }

  private native long GetCurrentKey_9();
  public vtkInformationKey GetCurrentKey() {
    long temp = GetCurrentKey_9();

    if (temp == 0) return null;
    return (vtkInformationKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkInformationIterator() { super(); }

  public vtkInformationIterator(long id) { super(id); }
  public native long   VTKInit();

}
